@@ -1,16 +1,14 @@
 #' Visualize well-known text area's on a map.
 #'
 #' This can be helpful in visualizing the area in which you are searching for
-#' occurrences with the \code{\link{occ}} function.
+#' occurrences with the [occ()] function.
 #'
 #' @export
-#' @importFrom whisker whisker.render
-#'
 #' @param x Input well-known text area (character)
 #' @param zoom Zoom level, defaults to 6 (numeric)
 #' @param maptype Map type, default is terrain (character)
 #' @param browse Open in browser or not. If not, gives back 
-#' path to html file. Default: \code{TRUE} (logical)
+#' path to html file. Default: `TRUE` (logical)
 #'
 #' @details Uses Mapbox's map layers, openes in your default browser
 #'
@@ -31,28 +29,21 @@
 #' poly2 <- 'POLYGON((-125 38.4,-125 40.9,-121.8 40.9,-121.8 38.4,-125 38.4))'
 #' wkt_vis(poly2, browse = FALSE)
 #' }
-
 wkt_vis <- function(x, zoom = 6, maptype = "terrain", browse = TRUE) {
   long = lat = group = NULL
+  
   stopifnot(!is.null(x))
   stopifnot(is.character(x))
-
-  out <- wkt_read(gsub("\n|\n\\s+", "", strtrim(x)))
-  
-  if (inherits(out$coordinates[,,1], "matrix")) {
-    longs <- data.frame(out$coordinates[,,1])
-    lats <- data.frame(out$coordinates[,,2])
-  } else {
-    longs <- t(data.frame(out$coordinates[,,1]))
-    lats <- t(data.frame(out$coordinates[,,2]) )
-  }
-  tocentroid <- list()
-  dfs <- list()
-  for (i in 1:NROW(longs)) {
-    tocentroid[[i]] <- tmp <- data.frame(long = as.numeric(longs[i,]), lat = as.numeric(lats[i,]))
-    dfs[[i]] <- apply(tmp, 1, function(x) as.list(x[c('long','lat')]))
-  }
-  centroid <- get_centroid(do.call("rbind", tocentroid))
+  x <- gsub("\n|\n\\s+", "", strtrim(x))
+  out <- wicket::wkt_coords(x)
+  centroid <- wicket::wkt_centroid(x)
+  dfs <- unname(lapply(split(out, out$ring), function(z) {
+    unname(
+      apply(z, 1, function(x) {
+        as.list(stats::setNames(x[c('lng','lat')], c('long', 'lat')))
+      })
+    )
+  }))
   
   whiskout <- list()
   for (i in seq_along(dfs)) {
@@ -60,21 +51,13 @@ wkt_vis <- function(x, zoom = 6, maptype = "terrain", browse = TRUE) {
     whiskout[[i]] <- whisker.render(features)
   }
   rend <- paste0(map_header, paste(whiskout, sep = "", collapse = ","), map_end)
-  
-  foot <- sprintf(footer, centroid[2], centroid[1], zoom)
+  foot <- sprintf(footer, centroid$lat, centroid$lng, zoom)
   res <- paste(rend, foot)
   tmpfile <- tempfile(pattern = 'spocc', fileext = ".html")
   write(res, file = tmpfile)
   if (browse) browseURL(tmpfile) else tmpfile
 }
 
-get_centroid <- function(x) {
-  x <- unname(as.matrix(x))
-  geojson <- jsonlite::toJSON(list(type = "Polygon", coordinates =  list(x)), auto_unbox = TRUE)
-  cent$eval(sprintf("var out = centroid(%s);", geojson))
-  cent$get("out.geometry.coordinates")
-}
-
 map_header <- '
 <!DOCTYPE html>
 <html>
@@ -82,8 +65,8 @@ map_header <- '
 <meta charset=utf-8 />
 <title>spocc WKT Viewer</title>
 <meta name="viewport" content="initial-scale=1,maximum-scale=1,user-scalable=no" />
-<script src="https://api.tiles.mapbox.com/mapbox.js/v2.2.2/mapbox.js"></script>
-<link href="https://api.tiles.mapbox.com/mapbox.js/v2.2.2/mapbox.css" rel="stylesheet" />
+<script src="https://api.tiles.mapbox.com/mapbox.js/v3.0.1/mapbox.js"></script>
+<link href="https://api.tiles.mapbox.com/mapbox.js/v3.0.1/mapbox.css" rel="stylesheet" />
 <style>
   body { margin:0; padding:0; }
   #map { position:absolute; top:0; bottom:0; width:100%; }
